@@ -78,7 +78,7 @@ def display_alert(args,printer):
     alert_message = args['alert_message']
     urgency = args['urgency']
     if debug: 
-        printer ("title/message/urgency", alert_title + "/" + alert_message + "/" + urgency)
+        printer ("title/message/urgency", str(alert_title) + "/" + str(alert_message) + "/" + str(urgency))
     cmd = construct_notification_command(alert_title, alert_message, urgency)
     # pdb.set_trace()
     if debug: 
